/* switches.c
 * Part of the RTAudio.Client project.
 * This file parses the options (switches) given to the argument and
 * creates an RTA_switches struct with all options and arguments inside.
 * It returns a pointer to that struct.
 * Written by Electronic One <eo@autobahn.mb.ca>
 */

#include <string.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>

#include "switches.h"
#include "errorcodes.h"
#include "exit.h"
#include "modes.h"

SW *parse_switches(int argc, char *argv[])
{
   SW *sw;
   
   /* Temp variable for parsing */
   int opt;
   
   if((sw = (SW *) malloc(sizeof(SW))) == NULL)
     {
	perror("Insifficient memory");
	t_exit(NO_MEM);
     }

   /* Init everything at 0 */
   bzero(sw, sizeof(SW));
   
   /* Parse program switches */
   while((opt = getopt(argc, argv, "c:i:o:vh")) != -1)
     {
	switch(opt)
	  {
	   case 'c' : sw->connect   = 1; 
	     bcopy(optarg, &sw->host_name[0], strlen(optarg) + 1); 
	     break;
	   case 'i' : sw->useinput  = 1;
	     bcopy(optarg, &sw->inf_name[0], strlen(optarg));
	     break;
	   case 'o' : sw->useoutput = 1;
	     bcopy(optarg, &sw->outf_name[0], strlen(optarg));
	     break;
	   case 'v' : sw->showver   = 1; break;
	   case 'h' : sw->showhelp  = 1; break;
	  }
     }
   
   /* Determine operating mode */
   sw->mode = (argc > 1) ? MODE_TEXT : MODE_NCURSES;
   
   /* Make sure everything is in order before proceeding */

   if(sw->useinput && sw->connect)
     {
	nonsense("You can't read from two sources.  Use -h for help.\n");
	t_exit(WRONG_USAGE);
     }
   
   return sw;
}

void nonsense(char *msg)
{
   printf(msg);
}

